starcluster.logger.NullHandler

Package starcluster :: Module logger :: Class NullHandler |
[hide private]
[frames] | no frames]

# Class NullHandler

source code

Instance Methods | [hide private]
emit(self, record) Do whatever it takes to actually log the specified logging record. | source code
Inherited from `logging.Handler`: `__init__`, `acquire`, `close`, `createLock`, `flush`, `format`, `handle`, `handleError`, `release`, `setFormatter`, `setLevel` Inherited from `logging.Filterer`: `addFilter`, `filter`, `removeFilter`

Method Details | [hide private]

### emit(self, record) | source code
Do whatever it takes to actually log the specified logging record. This version is intended to be implemented by subclasses and so raises a NotImplementedError. Overrides: logging.Handler.emit (inherited documentation)